#!/bin/bash

#=========================================
# Author   : colben
#=========================================

set -euo pipefail
export LANG=en_US.UTF-8
trap Quit EXIT

[ 'x86_64' == "$(uname -m)" ] && ARCH='' || ARCH="-$(uname -m)"
ROOT_DIR="$(cd $(dirname $0) && pwd)"
VERSION=$1
IMAGE="harbor.colben.cn/general/$(basename ${0%.sh})$ARCH:${VERSION%.*}"

if [ -t 0 ]; then
    function Print { echo -e "\033[36;1m$(date +'[%F %T]')\033[32;1m $*\033[0m"; }
    function Warn { echo -e "\033[36;1m$(date +'[%F %T]')\033[33;1m $*\033[0m"; }
    function Error { echo -e "\033[36;1m$(date +'[%F %T]')\033[31;1m $*\033[0m"; exit 1; }
else
    function Print { echo -e "$(date +'[%F %T INFO]') $*"; }
    function Warn { echo -e "$(date +'[%F %T WARN]') $*"; }
    function Error { echo -e "$(date +'[%F %T ERROR]') $*"; exit 1; }
fi

function Quit {
    local exitCode=$?
    [ 0 -ne $exitCode ] && Error Failed to build or push image!
    [ -z "${END:-}" ] && echo && Error Interrupted manually!
    Print Succeeded to build and push image.
}

function YesOrNo {
    Warn $*
    local sw=
    while :; do
        read -p '(Yes/No/Quit) ' -n1 sw
        [[ "$sw" =~ ^Y|y$ ]] && echo && return 0
        [[ "$sw" =~ ^N|n$ ]] && echo && return 1
        [[ "$sw" =~ ^Q|q$ ]] && echo && exit 0
        [ -n "$sw" ] && echo
    done
}

function Update {
    Warn Preparing kafka $VERSION ...
    cd $ROOT_DIR/ADD
    rm -rf $(ls | grep -v ccmd || true)
    tar zxf /release/RUNTIME/kafka_2.13-$VERSION.tgz
    mv kafka_2.13-$VERSION kafka
    cp kafka/config/server.properties kafka/config/server.properties.sample
    sed -i '/^log4j\.rootLogger/clog4j.rootLogger=INFO, connectAppender' kafka/config/connect-log4j.properties
    sed -i '/^log4j\.rootLogger/clog4j.rootLogger=INFO, kafkaAppender' kafka/config/log4j.properties
    mkdir kafka/{data,logs}
    rm -rf kafka/site-docs
}

function Build {
    local yn
    cd $ROOT_DIR
    docker images --format='{{.Repository}}:{{.Tag}}' | grep "^$IMAGE$" \
        && Warn Removing image $IMAGE ... \
        && docker rmi $IMAGE
    Warn Building image: $IMAGE ...
    docker build --force-rm --build-arg ARCH="$ARCH" --build-arg VERSION="$VERSION" -t $IMAGE .
    YesOrNo Push image: $IMAGE? && docker push $IMAGE
}

function Main {
    Update
    Build
    END=1
}

# Start here
Main

